From: David Francis <david.fran...@amd.com>

Instead of having drm_dp_dpcd_read/write and
drm_dp_mst_dpcd_read/write as entry points into the
aux code, have drm_dp_dpcd_read/write handle both.

This means that DRM drivers can make MST DPCD read/writes.

v2: Fix spacing
v3: Dump dpcd access on MST read/writes

Reviewed-by: Lyude Paul <ly...@redhat.com>
Reviewed-by: Harry Wentland <harry.wentl...@amd.com>
Signed-off-by: David Francis <david.fran...@amd.com>
---
 drivers/gpu/drm/drm_dp_aux_dev.c | 12 ++----------
 drivers/gpu/drm/drm_dp_helper.c  | 30 ++++++++++++++++++++----------
 2 files changed, 22 insertions(+), 20 deletions(-)

diff --git a/drivers/gpu/drm/drm_dp_aux_dev.c b/drivers/gpu/drm/drm_dp_aux_dev.c
index 00610bd8d6c1..0780fc358389 100644
--- a/drivers/gpu/drm/drm_dp_aux_dev.c
+++ b/drivers/gpu/drm/drm_dp_aux_dev.c
@@ -162,11 +162,7 @@ static ssize_t auxdev_read_iter(struct kiocb *iocb, struct 
iov_iter *to)
                        break;
                }
 
-               if (aux_dev->aux->is_remote)
-                       res = drm_dp_mst_dpcd_read(aux_dev->aux, pos, buf,
-                                                  todo);
-               else
-                       res = drm_dp_dpcd_read(aux_dev->aux, pos, buf, todo);
+               res = drm_dp_dpcd_read(aux_dev->aux, pos, buf, todo);
 
                if (res <= 0)
                        break;
@@ -214,11 +210,7 @@ static ssize_t auxdev_write_iter(struct kiocb *iocb, 
struct iov_iter *from)
                        break;
                }
 
-               if (aux_dev->aux->is_remote)
-                       res = drm_dp_mst_dpcd_write(aux_dev->aux, pos, buf,
-                                                   todo);
-               else
-                       res = drm_dp_dpcd_write(aux_dev->aux, pos, buf, todo);
+               res = drm_dp_mst_dpcd_write(aux_dev->aux, pos, buf, todo);
 
                if (res <= 0)
                        break;
diff --git a/drivers/gpu/drm/drm_dp_helper.c b/drivers/gpu/drm/drm_dp_helper.c
index 54a6414c5d96..0cbf10727bd6 100644
--- a/drivers/gpu/drm/drm_dp_helper.c
+++ b/drivers/gpu/drm/drm_dp_helper.c
@@ -29,6 +29,7 @@
 #include <linux/i2c.h>
 #include <linux/seq_file.h>
 #include <drm/drm_dp_helper.h>
+#include <drm/drm_dp_mst_helper.h>
 #include <drm/drmP.h>
 
 #include "drm_crtc_helper_internal.h"
@@ -272,7 +273,7 @@ static int drm_dp_dpcd_access(struct drm_dp_aux *aux, u8 
request,
 
 /**
  * drm_dp_dpcd_read() - read a series of bytes from the DPCD
  * @aux: DisplayPort AUX channel
  * @offset: address of the (first) register to read
  * @buffer: buffer to store the register values
  * @size: number of bytes in @buffer
@@ -301,13 +302,18 @@ ssize_t drm_dp_dpcd_read(struct drm_dp_aux *aux, unsigned 
int offset,
         * We just have to do it before any DPCD access and hope that the
         * monitor doesn't power down exactly after the throw away read.
         */
-       ret = drm_dp_dpcd_access(aux, DP_AUX_NATIVE_READ, DP_DPCD_REV, buffer,
-                                1);
-       if (ret != 1)
-               goto out;
+       if (!aux->is_remote) {
+               ret = drm_dp_dpcd_access(aux, DP_AUX_NATIVE_READ, DP_DPCD_REV,
+                                        buffer, 1);
+               if (ret != 1)
+                       goto out;
+       }
 
-       ret = drm_dp_dpcd_access(aux, DP_AUX_NATIVE_READ, offset, buffer,
-                                size);
+       if (aux->is_remote)
+               ret = drm_dp_mst_dpcd_read(aux, offset, buffer, size);
+       else
+               ret = drm_dp_dpcd_access(aux, DP_AUX_NATIVE_READ, offset,
+                                        buffer, size);
 
 out:
        drm_dp_dump_access(aux, DP_AUX_NATIVE_READ, offset, buffer, ret);
@@ -317,7 +323,7 @@ EXPORT_SYMBOL(drm_dp_dpcd_read);
 
 /**
  * drm_dp_dpcd_write() - write a series of bytes to the DPCD
  * @aux: DisplayPort AUX channel
  * @offset: address of the (first) register to write
  * @buffer: buffer containing the values to write
  * @size: number of bytes in @buffer
@@ -334,8 +340,12 @@ ssize_t drm_dp_dpcd_write(struct drm_dp_aux *aux, unsigned 
int offset,
 {
        int ret;
 
-       ret = drm_dp_dpcd_access(aux, DP_AUX_NATIVE_WRITE, offset, buffer,
-                                size);
+       if (aux->is_remote)
+               ret = drm_dp_mst_dpcd_write(aux, offset, buffer, size);
+       else
+               ret = drm_dp_dpcd_access(aux, DP_AUX_NATIVE_WRITE, offset,
+                                        buffer, size);
+
        drm_dp_dump_access(aux, DP_AUX_NATIVE_WRITE, offset, buffer, ret);
        return ret;
 }
@@ -272,7 +273,7 @@ static int drm_dp_dpcd_access(struct drm_dp_aux *aux, u8 
 /**
  * drm_dp_dpcd_read() - read a series of bytes from the DPCD
- * @aux: DisplayPort AUX channel
+ * @aux: DisplayPort AUX channel (SST or MST)
  * @offset: address of the (first) register to read
  * @buffer: buffer to store the register values
@@ -317,7 +323,7 @@ EXPORT_SYMBOL(drm_dp_dpcd_read);
 /**
  * drm_dp_dpcd_write() - write a series of bytes to the DPCD
- * @aux: DisplayPort AUX channel
+ * @aux: DisplayPort AUX channel (SST or MST)
  * @offset: address of the (first) register to write
  * @buffer: buffer containing the values to write
-- 
2.17.1

_______________________________________________
amd-gfx mailing list
amd-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/amd-gfx

Reply via email to